import 'dart:async';
import 'package:flutter/material.dart';
import 'package:flutter_riverpod/flutter_riverpod.dart';
import 'package:intl/intl.dart';
import 'package:factory_signage_app/const/config.dart';
import 'package:factory_signage_app/const/dimens.dart';
import 'package:factory_signage_app/const/string.dart';
import 'package:factory_signage_app/widget/lines.dart';
import 'package:factory_signage_app/widget/progress_graph.dart';
import 'package:factory_signage_app/widget/progress_text.dart';
import 'package:factory_signage_app/widget/progress_title.dart';
import 'package:factory_signage_app/provider.dart';

class DailyGraph extends ConsumerStatefulWidget {
  const DailyGraph(
      {super.key, this.size = const Size(double.infinity, double.infinity)});

  final Size size;

  @override
  DailyGraphState createState() => DailyGraphState();
}

class DailyGraphState extends ConsumerState<DailyGraph> {
  late Timer _timer;
  List<int> _dailyGraphData = List.filled(lineNames.length, 0);

  @override
  void initState() {
    super.initState();
    _timer = Timer.periodic(
      const Duration(seconds: intervalUpdateGraph),
      (timer) {
        final lineSignalStatus = ref.watch(lineSignalStatusProvider);
        if (listTotal(_dailyGraphData) > maxProduction) {
          _dailyGraphData = List.filled(lineNames.length, 0);
        } else {
          for (int i = 0; i < _dailyGraphData.length; i++) {
            if (lineSignalStatus[i] == LineStatus.active) {
              _dailyGraphData[i] += productionPerUpdateGraph;
            }
          }
        }
        ref.watch(dailyGraphDataProvider.notifier).state = [..._dailyGraphData];
        setState(() {});
      },
    );
  }

  @override
  void dispose() {
    _timer.cancel();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    final Size widgetSize = MediaQuery.of(context).size;

    return SizedBox(
      width: widget.size.width,
      height: widget.size.height,
      child: Column(
        children: [
          ProgressTitle(
            dailyGraphTitle,
            size: Size(
              double.infinity,
              progressTitleHeightRatio * widgetSize.height,
            ),
          ),
          ProgressGraph(
            _dailyGraphData,
            size: Size(
              double.infinity,
              progressGraphHeightRatio * widgetSize.height,
            ),
            maxY: dailyGraphMaxY.toDouble(),
            interval: dailyGraphInterval.toDouble(),
          ),
          ProgressText(
            statistics: dailyGraphStatistics,
            number: NumberFormat('#,###').format(listTotal(_dailyGraphData)),
            unit: dailyGraphUnit,
            size: Size(
              double.infinity,
              progressTextHeightRatio * widgetSize.height,
            ),
          ),
        ],
      ),
    );
  }

  int listTotal(List<int> data) =>
      data.reduce((value, element) => value + element);
}
