import 'package:flutter/material.dart';
import 'package:factory_signage_app/const/colors.dart';
import 'package:factory_signage_app/const/dimens.dart';

class ProgressText extends StatelessWidget {
  const ProgressText({
    super.key,
    required this.statistics,
    required this.number,
    required this.unit,
    this.size = const Size(double.infinity, double.infinity),
  });

  final String statistics;
  final String number;
  final String unit;
  final Size size;

  @override
  Widget build(BuildContext context) {
    final Size widgetSize = MediaQuery.of(context).size;

    return SizedBox(
      width: size.width,
      height: size.height,
      child: progressText(widgetSize),
    );
  }

  Widget progressText(Size widgetSize) {
    return Container(
      color: graphTextBackgroundColor,
      child: Padding(
        padding: const EdgeInsets.only(left: 10, right: 10, bottom: 5),
        child: Row(
          crossAxisAlignment: CrossAxisAlignment.end,
          children: [
            Text(
              statistics,
              style: TextStyle(
                color: textBlackColor,
                fontSize:
                    progressTextCharacterFontSizeRatio * widgetSize.height,
                fontWeight: FontWeight.w700,
              ),
            ),
            Expanded(
              child: Text(
                number,
                style: TextStyle(
                  color: textBlackColor,
                  fontSize: progressTextNumberFontSizeRatio * widgetSize.height,
                  fontWeight: FontWeight.w800,
                ),
                textAlign: TextAlign.right,
              ),
            ),
            Text(
              // Text Widget ignores trailing spaces, so add leading spaces
              ' $unit',
              style: TextStyle(
                color: textBlackColor,
                fontSize:
                    progressTextCharacterFontSizeRatio * widgetSize.height,
                fontWeight: FontWeight.w700,
              ),
            )
          ],
        ),
      ),
    );
  }
}
